# samPYling
![Static Badge](https://img.shields.io/badge/python-3.11-blue)
![Static Badge](https://img.shields.io/badge/status-Em_Desenvolvimento-green)


**samPYling**, auxilia o desenvolvimento de amostras probabilísticas e estimações de uma população baseado em diversas técnicas de amostragem.

# Licença

Este projeto foi feito sob os termos da licença AFL.